@@ -1,4 +1,6 @@
 from .Calculable import Calculable
 from .PolynomialSimple import PolynomialSimple
 from .PolynomialFraction import PolynomialFraction
+from .PolynomialCompact import PolynomialCompact
+from .Polynomial import Polynomial
 # from .Expression import Expression
