@@ -2,4 +2,4 @@ from .Calculable import *
 from .BilinearForm import *
 from .InnerProduct import *
 from .InnerProductSpace import *
-from .Operator import *
+from ..archive.Operator import *
